@@ -182,6 +182,9 @@ run:
             f.write("python3 -m pip install requests\n")
             if server_choice != "none":
                 f.write(f"python3 -m pip install {server_choice}\n")
+                if server_choice in ['fastapi', 'starlette', 'blacksheep', 'muffin', 'falcon', 'baize', 'emmett', 'quart']:
+                    # need to install uvicorn
+                    f.write("python3 -m pip install uvicorn\n")
             f.write("python3 -m pip install domonic\n")
             f.write("python3 -m pip freeze > requirements.txt\n")
         # call the bat file
@@ -196,6 +199,9 @@ run:
             f.write("python3 -m pip install requests\n")
             if server_choice != "none":
                 f.write(f"python3 -m pip install {server_choice}\n")
+                if server_choice in ['fastapi', 'starlette', 'blacksheep', 'muffin', 'falcon', 'baize', 'emmett', 'quart']:
+                    # need to install uvicorn
+                    f.write("python3 -m pip install uvicorn\n")
             f.write("python3 -m pip install domonic\n")
             f.write("python3 -m pip freeze > requirements.txt\n")
         # call the bash file
@@ -290,6 +296,14 @@ def parse_args():
         nargs="*",
         default=None,
     )
+    parser.add_argument(
+        "-q",
+        "--query",
+        help="pass a url and a css query",
+        type=str,
+        nargs="*",
+        default=None,
+    )
 
     # parser.add_argument('-u', '--ui', help="launches a UI")
     # parser.add_argument('-p', '--pyml2html', help="converts a .pyml template file to html", type=str)
@@ -384,6 +398,14 @@ def do_things(arguments):
         # except Exception as e:
         #     print('pip install html5lib')
 
+    if arguments.query is not None:
+        url, query = arguments.query
+        from domonic.window import window
+        window.location = url
+        results = window.document.querySelectorAll(query)
+        for result in results:
+            print(result)
+
     # if arguments.server is True:
     # port = domonic.get(arguments.server)
     # os.system('python -m http.server ' + port)
