@@ -5,12 +5,14 @@
 """
 
 import unittest
+
+from domonic.CDN import CDN_CSS, CDN_IMG, CDN_JS
+from domonic.html import img, link, script
+
 # import json
 # import requests
 # from mock import patch
 
-from domonic.html import script, link, img
-from domonic.CDN import CDN_JS, CDN_CSS, CDN_IMG
 
 
 class TestCase(unittest.TestCase):
