@@ -16,13 +16,13 @@ from domonic.style import *
 # from mock import patch
 
 
-
 class TestCase(unittest.TestCase):
     """ Tests for the dom package """
 
-    def setUp(self):
+    @classmethod
+    def setUpClass(cls):
         # can be used by all tests
-        self.page = html(
+        cls.page = html(
             head(
                 meta(_charset="utf-8"),
                 meta(**{"_http-equiv": "X-UA-Compatible"}, _content="IE=edge"),
@@ -183,6 +183,11 @@ class TestCase(unittest.TestCase):
             )
         )
 
+    def test_evaluate(self):
+        # headings = self.page.evaluate("/html/body//h2", self.page)  #, None, XPathResult.ANY_TYPE, None);
+        headings = self.page.evaluate("//h1", self.page)  #, None, XPathResult.ANY_TYPE, None);
+        assert len(headings) == 1, '"%s" != "%s"' % (len(headings), 1)
+
     def test_NodeList(self):
         nlist = self.page.body.childNodes
         assert isinstance(nlist, NodeList)
@@ -637,7 +642,7 @@ class TestCase(unittest.TestCase):
 
         result = self.page.querySelectorAll("li[class='nav-item']")
         expected = ["About", "Services", "Team", "Contact"]
-        print('yabadabadooooooo', result)
+        # print('yabadabadooooooo', result)
         for i, r in enumerate(result):
             assert r.textContent == expected[i]
         assert len(result) == 4
@@ -888,7 +893,6 @@ class TestCase(unittest.TestCase):
                 # print('The ' + bird.textContent + ' is endangered!')
                 assert 'The ' + bird.textContent + ' is endangered!' == 'The Philippine eagle is endangered!'
 
-
     def test_getElementsByTagName(self):
         content = ul(_id="birds").html(
             li("Orange-winged parrot"),
@@ -1605,5 +1609,85 @@ class NodeTest(TestCase):
     #     assert res == 'bar'
 
 
+class CommentTest(TestCase):
+    def setUp(self):
+        self.c = Comment('comment')
+        self.elm = p()
+
+    def test_node_type(self):
+        self.assertEqual(self.c.nodeType, self.c.COMMENT_NODE)
+        self.assertEqual(self.c.nodeName, '#comment')
+
+    def test_length(self):
+        self.assertEqual(self.c.length, 7)
+
+    def test_html(self):
+        self.assertEqual('<!--comment-->', str(self.c))
+
+    def test_append_comment(self):
+        self.elm.appendChild(self.c)
+        self.assertTrue(self.elm.hasChildNodes())
+        self.assertEqual(self.elm.length, 1)
+        self.assertEqual('<!--comment-->', str(self.elm.firstChild))
+
+
+class TestDocumentType(TestCase):
+    def setUp(self):
+        self.dtype = DocumentType()
+        self.node = Node()
+
+    def test_nodename(self):
+        self.assertEqual(self.dtype.nodeName, 'html')
+        self.assertEqual(self.dtype.name, 'html')
+
+    def test_parent(self):
+        self.node.appendChild(self.dtype)
+        self.assertIs(self.node, self.dtype.parentNode)
+
+    def test_html(self):
+        self.assertEqual(str(self.dtype), '<!DOCTYPE html>')
+
+
+class TestNodeList(TestCase):
+    def setUp(self):
+        super().setUp()
+        self.nl = NodeList(list(range(3)))
+
+    def test_length(self):
+        self.assertEqual(self.nl.length, 3)
+        self.assertEqual(len(self.nl), 3)
+
+    def test_index_access(self):
+        self.assertEqual(self.nl[1], 1)
+        self.assertEqual(self.nl[-1], 2)
+        self.assertEqual(self.nl[1:2], [1])
+        with self.assertRaises(IndexError):
+            self.nl[5]
+
+    def test_item(self):
+        self.assertEqual(self.nl.item(1), 1)
+        self.assertEqual(self.nl.item(-1), None)
+        self.assertEqual(self.nl.item(5), None)
+        with self.assertRaises(TypeError):
+            self.nl.item(slice(1, 2))
+
+    def test_contains(self):
+        self.assertTrue(1 in self.nl)
+        self.assertFalse(5 in self.nl)
+
+    def test_iteration(self):
+        l1 = [0, 1, 2]
+        for n in self.nl:
+            self.assertEqual(n, l1.pop(0))
+        l2 = [2, 1, 0]
+        for n in reversed(self.nl):
+            self.assertEqual(n, l2.pop(0))
+
+    def test_index(self):
+        self.assertEqual(self.nl.index(0), 0)
+        self.assertEqual(self.nl.index(1), 1)
+        self.assertEqual(self.nl.index(2), 2)
+
+
 if __name__ == '__main__':
     unittest.main()
